Session 16
task1: Implement vowel program using if else?
Condition1 condition2 condition3 (Pair conditions)
Note: When we are implementing pair conditions, we should use logical operators to concatinate (join or between).
like
and
or
about
and
True and True -> True
True and Flase -> False
False and True -> False
False or False -> False
When do we use operator?
-> When following statement should execute any one condition is true.
task2
Implement vowel program using if else and which should handle case sensitive?
-> Implement above vower program by using if else and which should handle case sensitive by using pre-defined method?
Design with o/p
task3
write a python program to accept student 3 subject marks and display the result?
Step1: Design with O/P
----------------------
Solution:-
Task4
Implement above program using 6 subjects
task5: Accept person age display person status
Tuesday, July 27, 2021
Python - day 16 if elif else continue
rpm: Find out what files are in my rpm package
rpm: Find out what files are in my rpm package
Use following syntax to list the files for already INSTALLED package:
rpm -ql package-name
Use following syntax to list the files for RPM package:
rpm -qlp package.rpm
Type the following command to list the files for gnupg*.rpm package file:
$ rpm -qlp rpm -qlp gnupg-1.4.5-1.i386.rpm
In this example, list files in a installed package called ksh:
$ rpm -ql ksh
See the files installed by a yum package named bash:
repoquery --list bash
repoquery -l '*bash*'
Syntax
repoquery -l {package-name-here}
repoquery -q -l {package-name-here}
repoquery -q -l --plugins {package-name-here}
repoquery -q -l --plugins *{package-name-here}*
repoquery -q -l --plugins http
repoquery -q -l --plugins ksh
here,
-l : List files in package
-q : For rpmquery compatibility (not needed)
--plugins : Enable plug-ins support
List the contents of a package using yum command
1. Open the terminal bash shell and type:
$ sudo yum install yum-utils
2. See the files installed by a yum package named bash:
$ repoquery --list bash
$ repoquery -l '*bash*'
https://www.cyberciti.biz/faq/howto-list-find-files-in-rpm-package/
Creating a CA-Signed Certificate for the Tomcat Server
Creating a CA-Signed Certificate for the Tomcat Server
Procedure
1. From the command prompt, go to the folder that contains the keytool.exe file:
- For Windows systems, go to C:\Program Files\Commvault\ContentStore\jre\bin.
- For Linux systems, go to /usr/lib/jvm/jdkx/bin.
2. To create the keystore file containing the key-pair/certificate to be signed, run the following command:
For Windows:
> keytool -genkey -alias tomcat -keyalg RSA -keystore "C:\mykeystore.jks" -ext SAN=dns:<domainname>
> keytool -genkey -alias tomcat -keyalg RSA -keystore "C:\mykeystore.jks" -ext "SAN=dns:myserv.eg.com,dns:cnameserv.eg.com,EMAIL:admin@eg.com"
For Linux:
# keytool -genkey -alias tomcat -keyalg RSA -keystore "/mykeystore.jks" -ext SAN=dns:<domainname>
3. Generate a CSR, run the following command:
keytool -certreq -keyalg RSA -alias tomcat -file C:\tomcat.csr -keystore C:\mykeystore.jks -validity <daysValid> -ext SAN=dns:<domainname>
keytool -certreq -keyalg RSA -alias tomcat -file C:\tomcat.csr -keystore C:\mykeystore.jks -validity 365 -ext SAN=dns:myserv.eg.com,dns:cnameserv.eg.com
4. Upload the CSR to the CA website, indicate the type of Tomcat server, and submit for signing.
5. Download the root, intermediate, and issued server/domain certificates.
6. Import each signed certificate that is issued by the CA using the following commands:
a. Root certificate:
keytool -import -alias root -keystore C:\mykeystore.jks -trustcacerts -file C:\valicert_class2_root.crt
b. Intermediate certificate:
keytool -import -alias intermed -keystore C:\mykeystore.jks -trustcacerts -file C:\gd_intermediate.crt
c. Issued server/domain certificate:
keytool -import -alias tomcat -keystore C:\mykeystore.jks -trustcacerts -file C:\server_certificate_whatevername.crt
Note: The keystore parameter must be the path to the keystore file that was used to generate the CSR. You must use the same keystore file throughout this procedure.
https://documentation.commvault.com/commvault/v11/article?p=50497.htm
7. Configure certificate
1. Stop the Tomcat Server.
2. Go to software_installation_path/Apache/Conf, and then back up the server.xml file that is part of the Apache configuration.
3. Copy the generated keystore file to software_installation_path/Apache.
4. For new installations of Version 11 SP9 or higher, in the server.xml file, modify the path to the generated keystore file and the keystore password values:
<Certificate certificateKeystoreFile="software_installation_path/Apache/your_file" certificateKeystorePassword="password" certificateKeystoreType="JKS"/>
8. Restart the service
a. Click Start and point to All Programs.
b. Click Commvault > Process Manager.
c. Under the Services tab, right-click a running service and then click Restart.
Python - day15 - if else
Session 14: 7/15/2021
Review
<syntax2>
if <condition>:
st1
st2
else:
st3
st4
a=int(input("Enter first number"))
b=int(input("Please enter 2nd number"))
if a>b:
print("A is greater then B")
else:
print("A is less than B"
====================================
When will you go for if elif else?
When we have more than 2 options to choose from based on condition, we will use if elif else.
In this case, if the condition is true, it will execute the statement and skips the rest of the statement.
On the other hand, if if condition is false, the control will go to elif part and executes and else part skips. but if elif is false, then executes the else part.
Write a python program to accept one letter and check if it is vowel or not?
Step1: Design with o/p
----------------------
o/p
-------------------------
enter your letter:
user enters a, store a into a variable called letter: a
return: it is vowel.
Enter your letter:
user enter b, store b into variable called letter: b
return: its not a vowel.
coding
--------
letter=input("Enter your letter")
if letter=='a':
print("It is a vowel")
elif letter=='e':
print("It is a vowel")
elif letter=='i':
print("It is a vowel')
elif letter=='o':
print("It is a vowel')
elif letter=='u':
print("It is a vowel")
else
print("It is not a vowel")
When you run this code
input - enter ur letter
user enters a
a=a
condition is true, the it is vowel and rest of the condition is skips.
run it again
user enters b
b=a -> false , skips
b=e and keep checking and it will go to else part and returns the value
it is not vowel.
In this code we have 6 conditions, one for vower and other for consonent
Task1:
implement above program by using if else?
letter=input("Enter a letter")
if(letter=='a'|'e'|'i'|'o'|'u'):
print("The letter is vowel")
else:
print("The letter is not a vowel"
task2
Implement above vowel program by using if else and which should handle casesensitive?
Step1: Design with 0/p
=======================
le=input("Enter a letter")
if (le=='A' or le='a' or le=='E' or le=='e' or le=='I' or le=='i' or le=='o' or le=='O' or le=='U' or le=='u'):
print(le, "is a vowel")
else
print(le, "is not a consonant")
Task3
-----
Write a python program to accept student 3 subject marks and display the result?
Step1: Design with O/P
----------------------
o/p
----------
Enter m1 marks: 60
enter m2 marks: 70
enter m3 marks: 80
m1+m2+m3 = 60+70+80 = totmarks
totmarks/3 -> avg marks
Now display result
result can be vary..
avgmarks=70
1. fail: if > 35 in any one subject
2. First division: if >=60
3. 2nd division: if avgmarks is between 50-59
4. 3rd divison: if avg marks is in between 35 to 49
so output form above command is
Result is: Fist division.
Review and complete these tasks before tomorrow class.
----------------------------------
task4:
implement above program using 6 subjects.
task5:
Accept person's age display person status?
Step1: Design with o/p
----------------------
1. if age>=59
print senior citizen
2. if age is in between 25 to 57
- working citizen
3. if age is in between 16 and 24
- college students
4. if age is between 4-15
- school kids
5. if kids are in between 1-3
playing kids
6. invalid selection
o/p
---------------
Please enter your age:
user enters 59
sore 59 into a variable 'age' so age=50
print:
you are senior citizen.
Python - Day14 - if else
Day/Session 14: Condition - 7/14/2021
Simple if
1. if lese
<syntax1>
if <condition>:
st1
else:
st2
When condition 1 is true it will execute statemetn1 and if fails, executes2.
first control will check the condition, if the condition is true, it will execute statement 1. it will skip the else statement.
if the condition is false, it will skip the if statement and goes to else part and executes else part.
<syntax2>
-------------
if <condition>:
st1
st2
else:
st3
st4
control will check the condition. if the condition is true it will enter into if condition and executes the statement 1 and statement 2. It skips the else part.
if condition is false, it skips the if part and conrol goes to else part and executes the else part.
eg1.
Write a python program to accept i and j value. Compare j and j values:
Step1: Design with o/p
----------------------
o/p
-----------------------
enter i value: 10
10 you store into i, i=10
enter j value: 5
store 5 int j, j=5
Write a condititon j is greater than i.
-> open your idle
File -> new file
i=int(input("Please enter i value"))
j=int(input("Enter j value"))
if i>j:
print("i is greater than j")
else:
print("j is greater than j")
run the program
enter 10, 10 will be stored in i
enter next number 5, stored in j.
next compares
i >j -> 10 > j -> condition is true so
it will execute if block. it skips else block.
There is a chance that user may type i=10 and j=10
what happens?
Since if condition evaluates and it is not true, it will skips the if blocks and goes to else part.
Since we don't have choice to write 3rd option, it will executes the else part.
to resolve this issue, we have to go to if, else, if part.
when do you use simple if?
-> we use simple if when particular condition need to verify.
when we have to c
in simple if, we have only one option. That means, when we have one option based on condition, we use simple if.
When do you use if else?
-> When we have 2 options, we want to execute one option based on condition.
3. if elif else
----------------
<SYNTAX>
---------
if <condition1>:
st1
elif <condition2>:
st2
else:
st3
when you have more than 2 options.
first control will check condition1. if condition is true, it will execute st1 and skip elif and else part.
2nd option:
control checks the condition1 and if condition1 is false, it will skip and goes to elif and checks condition2. If its true, it executes and skips else part.
if elif contition 2 is false, it will skip the condition2 and control goes to else part and executes st3.
--------------------------
Eg,
Implement compare i and j using if elif else?
write down all the options
i=int(input("Enter i value:")
j=int(input("Enter j value:")
if i>j:
print("i is greater than j")
elif:
print(j is greater than i")
else:
print("i is equal to j")
run the program:
enter i value: 10 -> 10 will be stored in i
enter j value: 5 -> 5 will stored in j
enter 5 and 10
5 greater than 10 -> skip if
compares elif part
conditon is true, executes
and prints the statemetn 2 and skips the else part
3rd, enter 10 and 10
compares first codition - flase,
end condition: false
executes else part.
you can use elif (3rd condition) but its not necessary. ..
Note: Do'nt use unnecesary conditions.
i=int(input("Enter i value:")
j=int(input("Enter j value:")
if i>j:
print("i is greater than j")
elif:
print(j is greater than i")
elif i==j:
print("i is equal to j")
Q. Implement above program using the requiremet below.
a. user enters 10 and 5
b. User enters 10 and 10 value
c. User enters 5 and 10 values.
Write the code for this condition
Step1: Design with O/p
o/p
---------------------------------
Enter i value: 10 - user enter 10
10 stored in 10
enter j value: 5
user enter 5 and stored in j.
and display
i is greater than j.
j value is : 10
i=int(input("Enter i value:")
j=int(input("Enter j value:")
if i>j:
print("i is greater than j")
print(The value of i is:", i)
elif j>i:
print(j is greater than i")
print("i value is:",j)
elif i==j:
print("i is equal to j")
print("i value us:", i)
print("j value is:",j)
10 adn 5
10>10
condition is true, executes the statemetn.
skips rest elif and else part
5>10 - false if skip
elif 5>10 -> false and executes
review the code above...
Python - day13 - if else
Day 13 - Python 7-13-2021
1. Simple if
<syntax1>
if <condition>:
st1
st2
by using relational operators
> -> Greater than
For eg,
-> 10>5 -> true,
10>20 -> false
10<20 -> true
10<5 -> False
10>=10 -> Yes -> True
10 <=20 -> True
10 <=10 -> True
10==10 -> True
10!=20 -> True
10!=10 -> False
< -> Less than
>=
<=
==
!=
coding
if 10>5:
print("Hi")
print("Hello")
we have two statements.
Which statement is conditional dependent statement?
the first one..
what is the output of this code?
Since first condition is true, it will print hi and hello is regular statement, so it will also prints the output
first condition 10>5 is checked and its true so print Hi is printed
the control goes to next statement, and prints hello.
next,
if 10>20:
print("Hi"
print("Hello")
here you will get only Hello outout
10>20 is false so it skips the statement. goes to next statement and reads it. It prints Hello.
<syntax2>
if <condition>:
statement1
st2
st3
we have two consitional statement. and one regular statement.
First condition is checked and if it is true, following two statements are printed.
lets say if condition is false, it will skip these two statements and go to next.
we have two statement conditional dependent and we have one conditional indenendent.
what happens when condition is false,
if condition is false, it will skip st1 and st2 and following statement is always executed.
if 10>5:
print("Hi")
print("Hello")
print("Bye")
what is the output?
->
Hi
Hello
Bye
10>10 true,
control will enter next statement and print Hi, Hello and goes to regular statement and prints bye.
if 10>50:
print("Hi")
print("Hello")
print("Bye")
what is the output?
o/p
--------
bye
10>50 will check and it false, it skips that section and goes to next section and prints bye.
eg,
Implement divide by zero error program by using simple if to handle run time error.
Design with output(o/p)
------------------------
Enter first number: 10
10 i sstored into a variable a.
Enter 2nd number: 0
user enter 0 and stored it into a variable b.
Please enter 2nd number other than zero: 5
user enter 5 and stored in c.
Division result is: 2
third statement is condition dependence. if user enter b==0:
checking the condition b.
3rd is condition accepting number other than 0.
So, we have to write a program. How to write a prigarm?
a=int(input("Enter first number:"))
b=int(input("Enter 2nd number:"))
if b==0:
b=int(input("Please enter 2nd number other than 0"))
c=a/b
print("Division result is:", c)
here, user enters first number 10 stored in a
user enters 0 and stored on b
it will prompt user to enter a number other than zero.
and result will be printed.
lets say frist user enter 10 and stored in a
2nd user enter 5 and stored in b.
review
o/p
---------------
first
enter first number executes and user enters 10 and stored in a
control goes to 2nd line and user enter 0 and 0 is stoed in b.
after that control will check the condition
0=0 which is true and executes next staetmetn.
please enter 2nd number other than zero.
lets assume, user enters 5 and stored in c.
now, control goes to next statement
c=10/5-2.0
now, print
Divison result is 2.0.
what happens
simple if is only verifies only once so we have to use loops if you have to verify multiple condition.
our user may not be gentle man who enter only one right answer.
Review yesterday's 5 home work.
Python - Day 12 - condition - if else
Day 12. Python
Write a python program to accept 2 numbers from the user and perform division and display division result?
Step1:
Step
vi test.py or open with idle
a=ent(input("Enter first number:"))
b=ent(input("Enter 2nd number:"))
c=a/b
print("Divison result is:", c)
run module
Enter first number:
enter 2nd number:
10 will be storing in a and so on
what happens if user enters 10 and 0?
error: run time error - zeroDivisionError: division by zero
value can not be divide by 0.
observation:
-----------
in the program above, when user entered first number 10 and second number 0, it will throw divide by zero error (run time error). Because of that program execution will be terminated abnormally.
run the program
enter first no: 10
enter 2nd no: 0
error:
Control Statement
in every programming language, control statement is very importand
how to handle run time errors?
- We can handle run time errors in 2 ways.
1. By using login
2. By using exception handling mechanism
1. By using login
- for this, we use control statement
2. Using exception hadling mechanism
-
What can we do using control statement?
- Using comtrol statement, we can control the program control execution flow according to our requirement.
When do we use control statement?
-> When we want to control the program execution flow as per our requirement.
We will go for control statements.
In python, we have 3 types of control statements.
1. Conditional statements
2. Loops
3. Transfer Statements
1. Conditional statements
Lets look at 4 scenarios
---------------------------------
statement 1
statement 2
statement 3
statement 4
statement 5
you have 5 lines of code and execution in order. We don't need any control statement
2nd scenario
---------------------------------
statement 1
statement 2
statement 3 ***
statement 4
statement 5
here staement3 may execute or may not execute. In this type of condition weneed conditional stement
---------------------------------
3nd
statement 1
statement 2
statement 3 ***
statement 4
statement 5
here statement 3 executing multiple time so we use look
---------------------------------
4th
statement 1
statement 2
statement 3 ***
statement 4
statement 5 ***
here, executing 1 and jumping to stetmenet 3 and jumping to 5, we use transfer statement.
as per the situation, we use one of the condition.
=============================
1. Conditional statements
What can we do with conditional statement?
- Using conditional statements, we can execute single statement or multiple statements based on condition.
When do we use conditional statements?
-> When you want to execute single statement or multiple statements based on condition, we will use conditional statements.
Types of conditional statements?
- In python, we have following conditional statements
1. Simple if
2. if else
3. if elif
4. multiple if
5. nested if
HW
Write a program using simple if, if else, if elif, multiple if, and nested if.
==============================
xcellis:
QXS-4 series chassis overview and qxs-456 chassis overview
xcellis I artico documentation center
Git branch show detached HEAD
Git branch show detached HEAD 1. List your branch $ git branch * (HEAD detached at f219e03) 00 2. Run re-set hard $ git reset --hard 3. ...
-
snmpconfig command allow you to managge snmpv1/v3 agent configuration on SAN switch. Event trap level is mapped with event severity level....
-
Git branch show detached HEAD 1. List your branch $ git branch * (HEAD detached at f219e03) 00 2. Run re-set hard $ git reset --hard 3. ...
-
2/09/2022 - Class Notes ReCap from last class Configmap Probes PV PVC Storage class ---------------- Todays agent create container - state...